class AppUserCredentials:

    types = {
        'userName': str,
        'password': str
    }

    def __init__(self):

        # username for app
        self.userName = None  # str

        # password for app
        self.password = None  # str
